==> aliyun-python-sdk-green-3.6.3.tar.gz: aliyun-python-sdk-green-3.6.3/aliyunsdkgreen/request/v20180509/ListSimilarityLibrariesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest
from aliyunsdkgreen.endpoint import endpoint_data

class ListSimilarityLibrariesRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'Green', '2018-05-09', 'ListSimilarityLibraries','green')
		self.set_uri_pattern('/green/similarity/library/list')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ClientInfo(self):
		return self.get_query_params().get('ClientInfo')

	def set_ClientInfo(self,ClientInfo):
		self.add_query_param('ClientInfo',ClientInfo)

==> aliyun-python-sdk-green-3.6.6.tar.gz: aliyun-python-sdk-green-3.6.6/aliyunsdkgreen/request/v20180509/ListSimilarityLibrariesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest
from aliyunsdkgreen.endpoint import endpoint_data

class ListSimilarityLibrariesRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'Green', '2018-05-09', 'ListSimilarityLibraries')
		self.set_uri_pattern('/green/similarity/library/list')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ClientInfo(self): # String
		return self.get_query_params().get('ClientInfo')

	def set_ClientInfo(self, ClientInfo):  # String
		self.add_query_param('ClientInfo', ClientInfo)
